var examples =
[
    [ "Surface_mesh_parameterization/ARAP_parameterization.cpp", "Surface_mesh_parameterization_2ARAP_parameterization_8cpp-example.html", null ],
    [ "Surface_mesh_parameterization/discrete_authalic.cpp", "Surface_mesh_parameterization_2discrete_authalic_8cpp-example.html", null ],
    [ "Surface_mesh_parameterization/lscm.cpp", "Surface_mesh_parameterization_2lscm_8cpp-example.html", null ],
    [ "Surface_mesh_parameterization/orbifold.cpp", "Surface_mesh_parameterization_2orbifold_8cpp-example.html", null ],
    [ "Surface_mesh_parameterization/seam_Polyhedron_3.cpp", "Surface_mesh_parameterization_2seam_Polyhedron_3_8cpp-example.html", null ],
    [ "Surface_mesh_parameterization/simple_parameterization.cpp", "Surface_mesh_parameterization_2simple_parameterization_8cpp-example.html", null ],
    [ "Surface_mesh_parameterization/square_border_parameterizer.cpp", "Surface_mesh_parameterization_2square_border_parameterizer_8cpp-example.html", null ],
    [ "Surface_mesh_parameterization/iterative_authalic_parameterizer.cpp", "Surface_mesh_parameterization_2iterative_authalic_parameterizer_8cpp-example.html", null ]
];